==> haskell-hasql-1.3.0.3-74-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hasql.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hasql
version: 1.3.0.3
id: hasql-1.3.0.3-I9d1QmtfT1B484tdbt0lF0
key: hasql-1.3.0.3-I9d1QmtfT1B484tdbt0lF0
license: MIT
copyright: (c) 2014, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/hasql
synopsis: An efficient PostgreSQL driver and a flexible mapping API
description:
    This package is the root of the \"hasql\" ecosystem.
    .
    The API is completely disinfected from exceptions. All error-reporting is explicit and is presented using the '\''Either'\'' type.
    .
    The version 1 is completely backward-compatible with 0.19.
category: Hasql, Database, PostgreSQL
abi: 69aac2ef4720d908ae31232f1ca44cc2
exposed: True
exposed-modules:
    Hasql.Connection Hasql.Decoders Hasql.Encoders Hasql.Session
    Hasql.Statement
hidden-modules: Hasql.Private.Prelude Hasql.Private.Errors
                Hasql.Private.PTI Hasql.Private.IO Hasql.Private.Session
                Hasql.Private.Connection Hasql.Private.PreparedStatementRegistry
                Hasql.Private.Settings Hasql.Private.Commands
                Hasql.Private.Decoders.Array Hasql.Private.Decoders.Composite
                Hasql.Private.Decoders.Value Hasql.Private.Decoders.Row
                Hasql.Private.Decoders.Result Hasql.Private.Decoders.Results
                Hasql.Private.Encoders.Array Hasql.Private.Encoders.Value
                Hasql.Private.Encoders.Params
import-dirs: /usr/lib/ghc-8.6.5/site-local/hasql-1.3.0.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/hasql-1.3.0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hasql-1.3.0.3
hs-libraries: HShasql-1.3.0.3-I9d1QmtfT1B484tdbt0lF0
depends:
    attoparsec-0.13.2.2-IaNz9bz10S32KGLwZomjal base-4.12.0.0
    base-prelude-1.3-4ZZNNsW3hao94Bjea11y2s bytestring-0.10.8.2
    bytestring-strict-builder-0.4.5.2-Kvty8QUtGqDAe6KNaGjSyA
    contravariant-1.5.1-AvnIJSQPha7KTZETo8YECh
    contravariant-extras-0.3.4-FcQOqizELA11CzEY1N4TUM
    data-default-class-0.1.2.0-1aigY0ifYUs4kfvMygEld7
    dlist-0.8.0.6-CQRMCGRgL5B3ZxhntX4iOr
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    hashtables-1.2.3.1-79DuoMzzH66HEDd83gGiOp
    loch-th-0.2.2-3CPdVoaGmAI4E58ziaHpq7 mtl-2.2.2
    placeholders-0.1-BvqrCQDGi4R6ufjrVRZiOw
    postgresql-binary-0.12.1.2-F0yapxUsAr8Evj1q0PkT0u
    postgresql-libpq-0.9.4.2-HyacS45qPUc33pszxfYdpM
    profunctors-5.4-5RAqDTPp5u29abm69elezE text-1.2.3.1
    text-builder-0.6.5.1-7COP5CPj5qJJWrUl3wdGrr transformers-0.5.6.2
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-hasql/html/hasql.haddock
haddock-html: /usr/share/doc/haskell-hasql/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hasql-1.3.0.3-75-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hasql.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hasql
version: 1.3.0.3
id: hasql-1.3.0.3-4vsGzNPBGOp2aKTNACes9I
key: hasql-1.3.0.3-4vsGzNPBGOp2aKTNACes9I
license: MIT
copyright: (c) 2014, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/hasql
synopsis: An efficient PostgreSQL driver and a flexible mapping API
description:
    This package is the root of the \"hasql\" ecosystem.
    .
    The API is completely disinfected from exceptions. All error-reporting is explicit and is presented using the '\''Either'\'' type.
    .
    The version 1 is completely backward-compatible with 0.19.
category: Hasql, Database, PostgreSQL
abi: 6f3291a7b572bc0aba6b6d54c8c0b7cf
exposed: True
exposed-modules:
    Hasql.Connection Hasql.Decoders Hasql.Encoders Hasql.Session
    Hasql.Statement
hidden-modules: Hasql.Private.Prelude Hasql.Private.Errors
                Hasql.Private.PTI Hasql.Private.IO Hasql.Private.Session
                Hasql.Private.Connection Hasql.Private.PreparedStatementRegistry
                Hasql.Private.Settings Hasql.Private.Commands
                Hasql.Private.Decoders.Array Hasql.Private.Decoders.Composite
                Hasql.Private.Decoders.Value Hasql.Private.Decoders.Row
                Hasql.Private.Decoders.Result Hasql.Private.Decoders.Results
                Hasql.Private.Encoders.Array Hasql.Private.Encoders.Value
                Hasql.Private.Encoders.Params
import-dirs: /usr/lib/ghc-8.6.5/site-local/hasql-1.3.0.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/hasql-1.3.0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hasql-1.3.0.3
hs-libraries: HShasql-1.3.0.3-4vsGzNPBGOp2aKTNACes9I
depends:
    attoparsec-0.13.2.2-IaNz9bz10S32KGLwZomjal base-4.12.0.0
    base-prelude-1.3-4ZZNNsW3hao94Bjea11y2s bytestring-0.10.8.2
    bytestring-strict-builder-0.4.5.2-Kvty8QUtGqDAe6KNaGjSyA
    contravariant-1.5.1-AvnIJSQPha7KTZETo8YECh
    contravariant-extras-0.3.4-FcQOqizELA11CzEY1N4TUM
    data-default-class-0.1.2.0-1aigY0ifYUs4kfvMygEld7
    dlist-0.8.0.6-CQRMCGRgL5B3ZxhntX4iOr
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    hashtables-1.2.3.1-79DuoMzzH66HEDd83gGiOp
    loch-th-0.2.2-3CPdVoaGmAI4E58ziaHpq7 mtl-2.2.2
    placeholders-0.1-BvqrCQDGi4R6ufjrVRZiOw
    postgresql-binary-0.12.1.2-33CYw6emBLoAP5KWF9sry9
    postgresql-libpq-0.9.4.2-HyacS45qPUc33pszxfYdpM
    profunctors-5.4-5RAqDTPp5u29abm69elezE text-1.2.3.1
    text-builder-0.6.5.1-7COP5CPj5qJJWrUl3wdGrr transformers-0.5.6.2
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-hasql/html/hasql.haddock
haddock-html: /usr/share/doc/haskell-hasql/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
